ArmVcpuTimer

Struct ArmVcpuTimer 

pub struct ArmVcpuTimer { /* private fields */ }
Timer state owned by one vCPU.

Implementations

Source

impl ArmVcpuTimer

pub const fn new( config: ArmTimerVmConfig, guest_hypervisor_control: u64, ) -> Self

Creates reset timer state for one vCPU.

pub fn snapshot(&self) -> ArmVcpuResult<ArmTimerSnapshot>

Returns an immutable snapshot while the timer is not loaded.

pub fn context_mut( &mut self, kind: ArmTimerKind, ) -> ArmVcpuResult<&mut ArmTimerContext>

Returns a mutable timer context while the timer is not loaded.

pub const fn config(&self) -> ArmTimerVmConfig

Returns the VM-wide timer configuration.

pub fn guest_counter( &self, kind: ArmTimerKind, physical_counter: u64, ) -> ArmVcpuResult<u64>

Reads one guest counter from the host physical counter.

pub fn read_control( &self, kind: ArmTimerKind, physical_counter: u64, ) -> ArmVcpuResult<u32>

Reads one timer’s control register.

pub fn read_tval( &self, kind: ArmTimerKind, physical_counter: u64, ) -> ArmVcpuResult<u32>

Reads one timer’s timer-value register.

pub fn read_compare(&self, kind: ArmTimerKind) -> ArmVcpuResult<u64>

Reads one timer’s compare-value register.

pub fn write_control(&mut self, kind: ArmTimerKind, value: u32) -> ArmVcpuResult

Writes one timer’s control register.

pub fn write_tval( &mut self, kind: ArmTimerKind, physical_counter: u64, value: u32, ) -> ArmVcpuResult

Writes one timer’s timer-value register.

pub fn write_compare(&mut self, kind: ArmTimerKind, value: u64) -> ArmVcpuResult

Writes one timer’s compare-value register.

pub fn load(&mut self, registers: &mut impl ArmTimerRegisters) -> ArmVcpuResult

Loads the direct virtual timer into hardware.

pub fn put(&mut self, registers: &mut impl ArmTimerRegisters) -> ArmVcpuResult

Saves and stops the direct virtual timer before restoring the host epoch.

pub fn reset(&mut self) -> ArmVcpuResult

Resets both timer contexts.